struct Zone {
polygon: Polygon,
center: Pt2D,
pct_overlap: f64,
homes: Vec<(BuildingID, usize)>,
workplaces: Vec<(BuildingID, usize)>,
borders: MapBorders,
}Fields
polygon: Polygoncenter: Pt2Dpct_overlap: f64homes: Vec<(BuildingID, usize)>workplaces: Vec<(BuildingID, usize)>borders: MapBordersImplementations
Sourceimpl Zone
impl Zone
Sourcefn pick_home(
&self,
mode: TripMode,
map: &Map,
rng: &mut XorShiftRng,
) -> Option<(TripEndpoint, TripEndpoint)>
fn pick_home( &self, mode: TripMode, map: &Map, rng: &mut XorShiftRng, ) -> Option<(TripEndpoint, TripEndpoint)>
Returns endpoints to (leave home, goto home). These’re usually the same, except in some cases of border trips using divided one-ways.
Sourcefn pick_workplace(
&self,
mode: TripMode,
map: &Map,
rng: &mut XorShiftRng,
) -> Option<(TripEndpoint, TripEndpoint)>
fn pick_workplace( &self, mode: TripMode, map: &Map, rng: &mut XorShiftRng, ) -> Option<(TripEndpoint, TripEndpoint)>
Returns endpoints to (leave work, goto work). These’re usually the same, except in some cases of border trips using divided one-ways.
fn pick_borders( &self, mode: TripMode, map: &Map, rng: &mut XorShiftRng, ) -> Option<(TripEndpoint, TripEndpoint)>